#ifndef PIRPANELNAMES_H
#define PIRPANELNAMES_H

enum PIRPanelName
{
  Main_Panel,
  Utility_Panel,
  Keypad_Panel,
  Menu_Panel,
  Media_Panel,
  Media2_Panel,
  Record_Panel,
  TV_Panel,
  Input_Panel,
  Adjust_Panel,
  AC_Panel,
  Favorites_Panel,
  Last_Panel_Marker // Used when traversing this enumeration.
};


#endif // PIRPANELNAMES_H
